@@ -4,7 +4,6 @@ process.env.CHROME_BIN = puppeteer.executablePath();
 module.exports = function(params) {
   'use strict';
   return function(config) {
-
     return config.set({
       basePath: '',
       frameworks: ['mocha', 'sinon-chai'],
@@ -16,15 +15,22 @@ module.exports = function(params) {
         ['tests/**/*.test.js']
       ),
       exclude: [],
-      reporters: ['dots', 'coverage', 'junit'],
+      reporters: ['dots', 'coverage', 'junit', 'progress', 'html'],
       port: 9876,
       colors: true,
       logLevel: config.LOG_INFO,
       autoWatch: true,
-      browsers: ['ChromeHeadless'],
+      browsers: ['ChromeHeadlessNoSandbox'],
       captureTimeout: 60000,
       singleRun: true,
 
+      customLaunchers: {
+        ChromeHeadlessNoSandbox: {
+          base: 'ChromeHeadless',
+          flags: ['--no-sandbox']
+        }
+      },
+
       coverageReporter: {
         type: 'html',
         dir: 'tests/coverage'
@@ -32,9 +38,19 @@ module.exports = function(params) {
 
       junitReporter: {
         outputDir: 'tests/reports'
+      },
+
+      htmlReporter: {
+        outputFile: 'tests/unit-test-reports/units.html',
+        
+        // Optional
+        pageTitle: 'Bootbox',
+        subPageTitle: 'Unit test results, Grouped',
+        groupSuites: true,
+        useCompactStyle: true,
+        useLegacyStyle: false,
+        showOnlyFailed: false
       }
     });
-
   };
-
-};
+};
\ No newline at end of file
